==> devextreme-21.1.8-build-22012-0313.tgz: package/cjs/ui/diagram/ui.diagram.properties_toolbar.js <==
/**
 * DevExtreme (cjs/ui/diagram/ui.diagram.properties_toolbar.js)
 * Version: 21.1.7 (build 22012-0313)
 * Build date: Wed Jan 12 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.default = void 0;
var _uiDiagram = _interopRequireDefault(require("./ui.diagram.toolbar"));
var _diagram = _interopRequireDefault(require("./diagram.commands_manager"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var DiagramPropertiesToolbar = function(_DiagramToolbar) {
    _inheritsLoose(DiagramPropertiesToolbar, _DiagramToolbar);

    function DiagramPropertiesToolbar() {
        return _DiagramToolbar.apply(this, arguments) || this
    }
    var _proto = DiagramPropertiesToolbar.prototype;
    _proto._getCommands = function() {
        return _diagram.default.getPropertiesToolbarCommands()
    };
    return DiagramPropertiesToolbar
}(_uiDiagram.default);
var _default = DiagramPropertiesToolbar;
exports.default = _default;
module.exports = exports.default;
module.exports.default = exports.default;

==> devextreme-21.1.10-build-22152-0340.tgz: package/cjs/ui/diagram/ui.diagram.properties_toolbar.js <==
/**
 * DevExtreme (cjs/ui/diagram/ui.diagram.properties_toolbar.js)
 * Version: 21.1.9 (build 22152-0340)
 * Build date: Wed Jun 01 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.default = void 0;
var _uiDiagram = _interopRequireDefault(require("./ui.diagram.toolbar"));
var _diagram = _interopRequireDefault(require("./diagram.commands_manager"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var DiagramPropertiesToolbar = function(_DiagramToolbar) {
    _inheritsLoose(DiagramPropertiesToolbar, _DiagramToolbar);

    function DiagramPropertiesToolbar() {
        return _DiagramToolbar.apply(this, arguments) || this
    }
    var _proto = DiagramPropertiesToolbar.prototype;
    _proto._getCommands = function() {
        return _diagram.default.getPropertiesToolbarCommands()
    };
    return DiagramPropertiesToolbar
}(_uiDiagram.default);
var _default = DiagramPropertiesToolbar;
exports.default = _default;
module.exports = exports.default;
module.exports.default = exports.default;
